# nav

[![Travis CI build status (Linux)](https://travis-ci.org/jmagnusson/nav.svg?branch=master)](https://travis-ci.org/jmagnusson/nav)
[![PyPI version](https://img.shields.io/pypi/v/nav.svg)](https://pypi.python.org/pypi/nav/)
[![Downloads from PyPI per month](https://img.shields.io/pypi/dm/nav.svg)](https://pypi.python.org/pypi/nav/)
[![License](https://img.shields.io/pypi/l/nav.svg)](https://pypi.python.org/pypi/nav/)
[![Available as wheel](https://img.shields.io/pypi/wheel/nav.svg)](https://pypi.python.org/pypi/nav/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/nav.svg)](https://pypi.python.org/pypi/nav/)
[![PyPI status (alpha/beta/stable)](https://img.shields.io/pypi/status/nav.svg)](https://pypi.python.org/pypi/nav/)
[![Coverage Status](https://coveralls.io/repos/github/jmagnusson/nav/badge.svg?branch=master)](https://coveralls.io/github/jmagnusson/nav?branch=master)
[![Code Health](https://landscape.io/github/jmagnusson/nav/master/landscape.svg?style=flat)](https://landscape.io/github/jmagnusson/nav/master)

Make requests to Microsoft Dynamics NAV Web Services
